# Odoo JID

This is a plugin for the [Odoo] suite of business management software that
adds a Jabber ID (JID) field to your customer and partner info.


## License

The package may be used under the terms of the Apache 2.0 License a copy of
which may be found in the [LICENSE] file.

Unless you explicitly state otherwise, any contribution submitted for inclusion
in the work by you shall be licensed as above, without any additional terms or
conditions.


[Odoo]: https://www.odoo.com/
[LICENSE]: https://codeberg.org/atlbikeshed/odoo-jid/raw/branch/main/LICENSE
